/*
 *   Require JDK 1.3
 *           
 *   Copyright (C) 1999  Andrea Gini
 *
 *   This work was based on some code written by Andea Anzani
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *   Send questions or suggestions to ginian@tiscalinet.it
 *
 */

import javax.swing.*;
import java.awt.*;
import java.net.*;
import java.awt.image.BufferedImage;

public class GuiTrasparente extends JFrame
{
  public GuiTrasparente()
  {
    super("Gui Trasparente"); 
    setSize(300,400);

    //imposta il ContentPane come non opaco
    ((JPanel)getContentPane()).setOpaque(false);
    // Crea l'oggetto che deve dipingere una texture sul fondo (vedi in coda al programma)
    URL imageLocation = BackgroundRenderer.class.getResource("Texture_wood_004.jpg");
    BackgroundRenderer texture = new BackgroundRenderer(imageLocation);
    // aggiunge la texture nel livello piu' basso del LayeredPane
    getLayeredPane().add(texture, new Integer(Integer.MIN_VALUE));
    // imposta dimensioni infinite, altrimenti non si vede niente
    texture.setBounds(0,0,5000,5000);

    // Crea una MenuBar trasparente
    JMenuBar mb = new JMenuBar();
    mb.setOpaque(true);
    mb.setBackground(new Color(200,150,100,175));
      JMenu fileMenu = new JMenu("File");
      fileMenu.setOpaque(true);
      fileMenu.setBackground(new Color(200,150,100,20));
        JMenuItem newItem = new JMenuItem("New");
        newItem.setOpaque(true);
        newItem.setBackground(new Color(0,0,0,40));
        JMenuItem openItem = new JMenuItem("Open");
        openItem.setOpaque(true);
        openItem.setBackground(new Color(0,0,0,40));  
        JMenuItem closeItem = new JMenuItem("Close");
        closeItem.setOpaque(true);
        closeItem.setBackground(new Color(0,0,0,40));                    
      fileMenu.add(newItem);
      fileMenu.add(openItem);
      fileMenu.add(closeItem);       
    mb.add(fileMenu);

    // Crea una JToolBar trasparente
    JToolBar tb = new JToolBar();
    tb.setOpaque(true);
    tb.setBackground(new Color(210,150,200,175));
        JButton newButton = new JButton("New");
        newButton.setOpaque(true);
        newButton.setBackground(new Color(200,150,200,0));
        JButton openButton = new JButton("Open");
        openButton.setOpaque(true);
        openButton.setBackground(new Color(200,150,200,0));  
        JButton closeButton = new JButton("Close");
        closeButton.setOpaque(true);
        closeButton.setBackground(new Color(200,150,200,0)); 
    tb.add(newButton);
    tb.add(openButton);
    tb.add(closeButton);

    // Crea una JTextArea trasparente    
    JTextArea ta = new JTextArea();
    ta.setOpaque(true);
    ta.setBackground(new Color(0,0,0,0));

    // aggiunge i componenti alla GUI
    setJMenuBar(mb);
    getContentPane().add(BorderLayout.CENTER,new JScrollPane(ta));
    getContentPane().add(BorderLayout.NORTH,tb);

    setVisible(true);
  }
  /**
   * Questo componente si occupa di disegnare una Texture
   * utilizzando l'API 2D
   */
class BackgroundRenderer extends JComponent {	   
  private boolean empty=false;
  private TexturePaint texture;

  public BackgroundRenderer(URL imageUrl) {
    // Carica l'immagine
    try {
      Image img = this.getToolkit().getImage(imageUrl);
      MediaTracker tracker = new MediaTracker(this);
      tracker.addImage(img, 0);
      tracker.waitForID(0);

      int iw = img.getWidth(this);
      int ih = img.getHeight(this);
      BufferedImage bi = new BufferedImage(iw, ih, BufferedImage.TYPE_INT_RGB);
      Graphics2D tG2 = bi.createGraphics();
      tG2.drawImage(img, 0, 0, this);
      Rectangle r = new Rectangle(0,0,iw,ih);
      texture = new TexturePaint(bi,r);
    }
     catch (Exception e) {
       e.printStackTrace();
     }
  }
   
  public void paintComponent(Graphics g) {
    if(!empty) {
      Graphics2D g2 = (Graphics2D) g;
      int w = getSize().width;
      int h = getSize().height;
      g2.setPaint((TexturePaint) texture);
      g2.fill(new Rectangle(0,0,w,h));
    }
  }
  public Dimension getPreferredSize() {
    return new Dimension(super.getSize());
  }
  public Dimension getMinimumSize() {
    return getPreferredSize();
  }
  public void setEmpty() {
    empty=true;
    repaint();
  }
}
public static void main(String argv[]) {
  GuiTrasparente t = new GuiTrasparente();
}
}